CUE Cube loading and evaluation
This module handles loading CUE Cubes and evaluating them to extract file definitions. A “Cube” is a CUE-based template that defines multiple files to generate for a project.
Structs
- Cube
- CUE Cube loader and evaluator
- Cube
Data - A CUE Cube containing file definitions
- Format
Config - Format configuration for a code file
- Project
File Definition - A project file definition from the cube
Enums
- File
Mode - File generation mode